# -*- coding: UTF-8 -*-

import sys

PY2 = sys.version_info.major == 2
PY3 = sys.version_info.major == 3

if PY3:
    import configparser
    import urllib.parse as urlparse
    text_type = str
    binary_type = bytes
    string_types = str
else:
    import ConfigParser as configparser
    import urlparse
    text_type = unicode
    binary_type = str
    string_types = basestring


def ensureStr(s, encoding='utf-8', errors='strict', safe=False):
    """ Взято из пакета python-six(= 1.14.0-2)
    Coerce *s* to `str`.
    For Python 2:
      - `unicode` -> encoded to `str`
      - `str` -> `str`
    For Python 3:
      - `str` -> `str`
      - `bytes` -> decoded to `str`
    """
    # Optimization: Fast return for the common case.
    if type(s) is str:
        return s
    if PY2 and isinstance(s, text_type):
        return s.encode(encoding, errors)
    elif PY3 and isinstance(s, binary_type):
        return s.decode(encoding, errors)
    elif not safe and not isinstance(s, (text_type, binary_type)):
        raise TypeError("not expecting type '%s'" % type(s))
    return s


def ensureBinary(s, encoding='utf-8', errors='strict'):
    """ Взято из пакета python-six(= 1.14.0-2)
    Coerce **s** to six.binary_type.
    For Python 2:
      - `unicode` -> encoded to `str`
      - `str` -> `str`
    For Python 3:
      - `str` -> encoded to `bytes`
      - `bytes` -> `bytes`
    """
    # Optimization: Fast return for the common case.
    if isinstance(s, binary_type):
        return s
    if isinstance(s, text_type):
        return s.encode(encoding, errors)
    raise TypeError("not expecting type '%s'" % type(s))
